<?php
require_once('request.php');
require_once('response.php');
require_once('error_response.php');

require_once('op5/auth/Auth.php');

$nacoma_path = '/opt/monitor/op5/nacoma/';
$ninja_path = '/opt/monitor/op5/ninja/';
$request = new Api_Request();

try {
        /* Fetch auth object without session support */
        $auth = Op5Auth::factory( array( 'session_key' => false ) );

        /* Login every time - not to keep session */
        if (!isset($_SERVER['PHP_AUTH_USER']) ||
                !isset($_SERVER['PHP_AUTH_PW']) ||
                !$auth->login( $_SERVER['PHP_AUTH_USER'], $_SERVER['PHP_AUTH_PW'] ) )
        {
                header( 'WWW-Authenticate: Basic realm="op5 Monitor API Access"' );
                throw new Api_Error_Response( 'Unauthorized', 401, 'You need to login to access this page' );
        }

        $request->set_auth($auth);

        switch($request->get_project_name()) {
                case 'config':
                        if(!$auth->authorized_for('api_config')) {
                                header( 'WWW-Authenticate: Basic realm="op5 Monitor API Access"' );
                                throw new Api_Error_Response( 'Unauthorized', 401, "You're not authorized to access this page, you need 'api_config' rights" );
                        }
                        require_once($nacoma_path.'api/http.php');
                        $response = generate_response($request);
                        echo $response->send($request);
                        break;
                case 'status':
                        if(!$auth->authorized_for('api_status')) {
                                header( 'WWW-Authenticate: Basic realm="op5 Monitor API Access"' );
                                throw new Api_Error_Response( 'Unauthorized', 401, "You're not authorized to access this page, you need 'api_status' rights" );
                        }
                        require_once(dirname(__FILE__).'/../livestatus.php');
                        $response = generate_response($request, $auth);
                        echo $response->send($request);
                        break;
                case 'report':
                        if(!$auth->authorized_for('api_report')) {
                                header( 'WWW-Authenticate: Basic realm="op5 Monitor API Access"' );
                                throw new Api_Error_Response( 'Unauthorized', 401, "You're not authorized to access this page, you need 'api_report' rights" );
                        }
                        require_once(dirname(__FILE__).'/../report.php');
                        $response = generate_response($request, $auth, $ninja_path);
                        echo $response->send($request);
                        break;
                case 'help':
                case '':
                        if ($request->get_output_format() === 'html') {
                                $response = new Api_Response('<h1>op5 Monitor API</h1><p>This is the op5 Monitor status API. Each Nagios object can be queried by using the following documentation.</p>', 200);
                                echo $response->send($request);
                                break;
                        }
                default:
                        $response = Api_Error_Response::with_usage('Invalid request', 400, $request);
                        echo $response->send($request);
        }
} catch (Api_Response $response) {
        echo $response->send($request);
}
